import { IapticStripe } from './iaptic-stripe';
import { Config } from './types';
import { Utils } from './utils';
export * from './iaptic-stripe';
export * from './refresh-scheduler';
export * from './utils';
export * from './types';
/**
 * Creates an Iaptic adapter for the specified payment platform
 * @param config - Configuration options for the adapter
 * @returns An initialized adapter instance
 * @throws Error if the specified adapter type is not supported
 * @example
 * ```ts
 * const iaptic = createAdapter({
 *   type: 'stripe',
 *   appName: 'my-app',
 *   apiKey: '1234567890',
 *   stripePublicKey: 'pk_test_...'
 * });
 * ```
 */
export declare function createAdapter(config: Config): IapticStripe;
/**
 * Main entry point for the Iaptic library
 */
export declare const IapticJS: {
    /** Current version of the IapticJS library */
    version: string;
    /** Function to create a new Iaptic adapter */
    createAdapter: typeof createAdapter;
    /** Stripe adapter class */
    IapticStripe: typeof IapticStripe;
    /** Utility functions */
    Utils: typeof Utils;
};
//# sourceMappingURL=index.d.ts.map