/**
 * Utility functions for the Iaptic library
 */
export declare class Utils {
    /**
     * Base64 encode a string
     * @param str String to encode
     */
    static base64Encode(str: string): string;
    /**
     * Get item from localStorage with type safety
     *
     * @param key Storage key
     * @param defaultValue Default value if not found
     */
    static storageGetJson<T>(key: string): T | null;
    /**
     * Get item from localStorage as string
     *
     * @param key Storage key
     */
    static storageGetString(key: string): string | null;
    /**
     * Set item in localStorage
     *
     * @param key Storage key
     * @param value Value to store
     */
    static storageSetJson(key: string, value: any): boolean;
    static storageSetString(key: string, value: string): boolean;
    /**
     * Remove item from storage
     *
     * @param key Storage key
     */
    static storageRemove(key: string): boolean;
    /**
     * Build URL with query parameters
     * @param baseUrl Base URL
     * @param params Query parameters
     */
    static buildUrl(baseUrl: string, params: Record<string, string>): string;
    /**
     * Format a price amount from micros
     */
    static formatCurrency(amountMicros: number, currency: string): string;
    /**
     * Format a ISO 8601 period in English
     *
     * @param period ISO 8601 period
     */
    static formatBillingPeriodEN(period: string): string;
}
